@@ -14,11 +14,12 @@ use Text::Template;
 
 use Pod::Tree::BitBucket;
 use Pod::Tree::StrStream;
+use Pod::Tree::HTML::LinkMap;
 
 use constant BGCOLOR => '#ffffff';
 use constant TEXT    => '#000000';
 
-our $VERSION = '1.23';
+our $VERSION = '1.24';
 
 sub new {
 	my ( $class, $source, $dest, %options ) = @_;
@@ -595,32 +596,6 @@ sub escape_2396 {
 	$text;
 }
 
-package Pod::Tree::HTML::LinkMap;
-use strict;
-use warnings;
-
-sub new {
-	my $class = shift;
-	bless {}, $class;
-}
-
-sub url {
-	my ( $link_map, $html, $target ) = @_;
-
-	my $depth = $html->{options}{depth};
-	my $base = join '/', ('..') x $depth;
-
-	my $page = $target->get_page;
-	$page =~ s(::)(/)g;
-	$page .= '.html' if $page;
-
-	my $section  = $target->get_section;
-	my $fragment = $html->escape_2396($section);
-
-	my $url = $html->assemble_url( $base, $page, $fragment );
-	$url;
-}
-
 __END__
 
 =head1 NAME
